==> next-ft-api-client-3.19.0.tgz: package/README.md <==
# next-ft-api-client
No caching, no models, no complexity, none of that or any of that.

```
npm install --save next-ft-api-client
```

```js
var api = require('next-ft-api-client');
```

## `.content(opts)` - get V2 content
- `uuid` - uuid (or array of uuids) of wanted content

If `uuid` is a string return a Promise that resolves with a V2 content object, if `uuid` is an array, returns a Promise that resolves with an array of V2 content objects.

## `.contentAnnotatedBy(opts)`
- `uuid` - uuid of thing wanted to select content by
- `count` - number of items of content to return (default 10)

Returns with a Promise that resolves with an array of V2 content objects.

## `.contentLegacy(opts)` - get V1 content
- `uuid` - uuid of wanted content

Returns with a Promise that resolves with a V1 content object.

## `.lists(opts)`
- `uuid` - uuid of wanted list

Returns with a Promise that resolves with a list.

## `.organisations(opts)`
- `uuid` - uuid of wanted organisation

Returns with a Promise that resolves with an organisation.

## `.people(opts)`
- `uuid` - uuid of wanted person

Returns with a Promise that resolves with a person.

## `.search(opts)`
- `filter` - search filter. Either an array of [ fieldname, value ] or an Elasticsearch filter object.
- `fields` - an array of source document fields to fetch
- `count` - number of documents to return (default 10)
- `offset` - number of documents to offset by (default 0)

Returns a promise that resolves an array of documents from the V3 Elasticsearch index.

## `.searchLegacy(opts)`
- `query` - query to search against. Either free text, a taxonomysearch e.g. `peopleId:"Mhkasfgoasfgjh"` or, when using elastic search, an elastic search query object
- `fields` - When using elastic search an array of fields to return
- `count` - number of items of content to return (default 10)
- `offset` - number of items of content to offset by (default 0)

Returns with a Promise that resolves with an array of V1 content objects (depending on options).

## `.things(opts)`
- `uuid` - uuid of wanted thing

Returns with a Promise that resolves with a thing.

## `.mapping(uuid, taxonomy)`
- `uuid` - uuid of thing to map
- `taxonomy` - taxonomy of thing to map

Returns with a Promise that resolves with the mapped concept.

## `.hui(opts)`
- `industry` - uuid of an industry
- `position` - uuid of a position
- `sector` - uuid of a sector
- `country` - uuid of a country
- `period` - time period to use e.g last-1-day, last-1-week (default last-1-day)
- `count` - number of UUIDs to return (default 10)

Returns with a Promise that resolves with a list.

==> next-ft-api-client-3.23.0.tgz: package/README.md <==
# next-ft-api-client
No caching, no models, no complexity, none of that or any of that.

```
npm install --save next-ft-api-client
```

```js
var api = require('next-ft-api-client');
```

## `.content(opts)`
- `uuid` - uuid (or array of uuids) of wanted content

If `uuid` is a string return a Promise that resolves with V3 Elasticsearch content, if `uuid` is an array, returns a Promise that resolves with an array of content.

## `.contentAnnotatedBy(opts)`
- `uuid` - uuid of thing wanted to select content by
- `count` - number of items of content to return (default 10)

Returns with a Promise that resolves with an array of V2 content objects.

## `.lists(opts)`
- `uuid` - uuid of wanted list

Returns with a Promise that resolves with a list.

## `.organisations(opts)`
- `uuid` - uuid of wanted organisation

Returns with a Promise that resolves with an organisation.

## `.people(opts)`
- `uuid` - uuid of wanted person

Returns with a Promise that resolves with a person.

## `.search(opts)`
- `filter` - search filter. Either an array of [ fieldname, value ] or an Elasticsearch filter object.
- `fields` - an array of source document fields to fetch
- `count` - number of documents to return (default 10)
- `offset` - number of documents to offset by (default 0)

Returns a promise that resolves an array of documents from the V3 Elasticsearch index.

## `.things(opts)`
- `identifierValue` - an array of source thing ids you wish to fetch
- `authority` - the authority the terms belong too (defaults to FT-TME: http://api.ft.com/system/FT-TME)

Returns with a Promise that resolves with an array of things.

## `.mapping(uuid, taxonomy)`
- `uuid` - uuid of thing to map
- `taxonomy` - taxonomy of thing to map

Returns with a Promise that resolves with the mapped concept.

## `.hui(opts)`
- `model` - string of the type of model you want returned (default 'content')
- `industry` - uuid of an industry
- `position` - uuid of a position
- `sector` - uuid of a sector
- `country` - uuid of a country
- `period` - time period to use e.g last-1-day, last-1-week (default last-1-day)
- `count` - number of UUIDs to return (default 10)

Returns with a Promise that resolves with a list.

## `.relatedTags(opts)`
- `id` - ID of tag to find related tags for (required)
- `taxonomies` - array of taxonomies to include within results (required)
- `range` - number of days to include within results (default 60)
- `size` - number of tags to return (default 12)

Returns with a Promise that resolves with an array of tags.
